%%%%%%%%%%  Lorenz System  %%%%%%%%%
%  xdot = sig*(y - x)
%  ydot = rx - y - xz
%  zdot = xy - bz
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% INPUT:
%  t: time array
%  x0: 3x1 vector of initial conditions
%  param: 3x1 vector of parameter [sig r b]'

%EX:
% x0 = [.1 0 .2]'; param = [10 28 8/3];
%[Xdot] = Lorenz_Mine(t, x0, param)

function Xdot = Lorenz_Mine(t, x0, param)

%Parameters
sig = param(1);
r   = param(2);
b   = param(3);

%Variables
x = x0(1);
y = x0(2);
z = x0(3);

%Lorenz System
dxdt    = sig*(y - x);
dydt    = r*x - y - x*z;
dzdt    = x*y - b*z;

Xdot = [dxdt dydt dzdt]';
