%%%% Computes the Lyapunov Exponents %%%%%%%%
% Input:
%    t0:          time start
%    tend:        time end
%    N            number of time points
%    x0            - nx1 column vector of initial conditions
%    sysNam        - function handle of dynamical system
%    LinearSysName - function hanle of Linearized dynamical system
%
%Ouput: 
%    lambda         - 1 by n numerical approx of Lyapunov Exponents
%    LE             - m by n matrix of timeseries of Lyapunov Exponents
%
%EX.
% param = [10, 28, 8/3]'; x0 = [0.1 0 0.1]';
% t0= 0; tend= 100; dt = 0.002; N=tend/dt;
% [t lambda LE] = LyapunovExpQR(0, tend, N, x0, 'Lorenz_Mine', 'Lorenz_Linear', param);


function [t lambda LE] = LyapunovExpQR(t0, tend, N, x0, sysName, LinearSysName, param)

n = length(x0);
Q = eye(n);
rho = zeros(n, 1);
IC = [x0; reshape(Q, n^2,1);  rho]';
%odeoptions = odeset('AbsTol', 1e-5);
%[t X] = ode45(@LyapunovSys_QR,[t0 tend], IC,odeoptions, sysName, LinearSysName, param);
[t X] = RK_LyapExp(IC, t0, tend, N, sysName, LinearSysName, param);

%Lyapunov Exponent Approximation
lambda = X(end, end - (n -1):end)/t(end)

%Lyapunov Exponents time series
LE = zeros(length(t), n);
for i = 1:n
    LE(:,i) = X(:,end-(i-1))./t';
end

